var FeedParserConsts =
{
	TYPE : 
	{
		RSS		: 'RSS',
		ATOM	: 'ATOM' 	
	},

	RSS : 
	{
		CHANNEL		: 'channel',
		ITEM		: 'item',
		TITLE		: 'title',
		LINK		: 'link',
		GUID		: 'guid',
		PUBDATE		: 'pubdate',
		DCDATE		: 'dc:date',
		ISPERMALINK : 'isPermaLink',
		TRUE		: 'true',
		FALSE		: 'false'
	},
	
	ATOM : 
	{
		ENTRY		: 'entry',
		TITLE		: 'title',
		LINK		: 'link',
		HREF		: 'href',
		MODIFIED	: 'modified',
		TYPE		: 'type',
		TEXTHTML	: 'text/html'
	}
}

function FeedElement(strTitle,strLink,strDate)
{
	this.Title	= strTitle;
	this.Link	= strLink;
	this.Date	= strDate;
}

function FeedParser(XMLDoc)
{
	this.Type	 = '';
	this.Title = '';
	this.Link	 = '';
	this.Items = new Array();

	this.Init = function(XMLDoc)
	{
		if(XMLDoc)
		{
			var XMLRoot = XMLDoc.documentElement;
			if(XMLRoot.tagName == 'parsererror')
			{
				return;
			}
			this.BuildFeed(XMLRoot);
		}
	};
	
	this.BuildFeed = function(XMLRoot)
	{
		var XMLFeedItems = this.GetFeedItems(XMLRoot);
		
		if(XMLFeedItems)
		{
			if(this.Type == FeedParserConsts.TYPE.RSS)
			{
				this.SetRSSFeedTitleLink(XMLRoot);
				this.BuildRSSFeedItems(XMLFeedItems);
			}
			else if(this.Type == FeedParserConsts.TYPE.ATOM)
			{
				this.SetATOMFeedTitleLink(XMLRoot);
				this.BuildATOMFeedItems(XMLFeedItems);
			}
		}
	};
	
	this.BuildRSSFeedItems = function(XMLFeedItems)
	{
		var strTitle	= '';
		var strLink		= '';
		var strDate		= '';
		
		var strURLFromLinkNode			= '';
		var strURLFromGUIDPermaLinkNode = '';
		
		var strTagName		= '';
		
		var XMLFeedItem		= null;
		var XMLChildNode	= null;
		for(var i=0;i<XMLFeedItems.length;i++)
		{
			XMLFeedItem = XMLFeedItems.item(i);
			for(var j=0;j<XMLFeedItem.childNodes.length;j++)
			{
				XMLChildNode = XMLFeedItem.childNodes[j];
				strTagName = XMLChildNode.tagName;
				if(typeof(strTagName) == 'string')
				{
					strTagName = strTagName.toLowerCase();
				}
				
				if(strTagName == FeedParserConsts.RSS.TITLE)
				{
					strTitle = XMLManager.GetXmlNodeValue(XMLChildNode);
				} 
				else if(strTagName == FeedParserConsts.RSS.LINK)
				{
					strURLFromLinkNode = XMLManager.GetXmlNodeValue(XMLChildNode);
				}
				else if(strTagName == FeedParserConsts.RSS.GUID)
				{
					strURLFromGUIDPermaLinkNode = this.GetRSSLinkFromXMLGUIDNode(XMLChildNode);
				}
				else if(strTagName == FeedParserConsts.RSS.PUBDATE)
				{
					strDate = XMLManager.GetXmlNodeValue(XMLChildNode);
				}
				else if(strTagName == FeedParserConsts.RSS.DCDATE)
				{
					strDate = XMLManager.GetXmlNodeValue(XMLChildNode);
				}
			}
			
			strLink = strURLFromLinkNode ? strURLFromLinkNode : strURLFromGUIDPermaLinkNode;
			
			if(strLink)
			{
				this.AddFeedElement(strTitle,strLink,strDate);
			}
			
			
		}
	};
	
	this.BuildATOMFeedItems = function(XMLFeedItems)
	{
		var strTitle	= '';
		var strLink		= '';
		var strDate		= '';
		
		var strTagName		= '';
		
		var XMLFeedItem		= null;
		var XMLChildNode	= null;
		for(var i=0;i<XMLFeedItems.length;i++)
		{
			XMLFeedItem = XMLFeedItems.item(i);
			for(var j=0;j<XMLFeedItem.childNodes.length;j++)
			{
				XMLChildNode = XMLFeedItem.childNodes[j];
				strTagName = XMLChildNode.tagName;
				if(typeof(strTagName) == 'string')
				{
					strTagName = strTagName.toLowerCase();
				}
				
				if(strTagName == FeedParserConsts.ATOM.TITLE)
				{
					strTitle = XMLManager.GetXmlNodeValue(XMLChildNode);
				}
				else if(strTagName == FeedParserConsts.ATOM.LINK)
				{
					strLink = this.GetATOMLinkFromXMLLinkNode(XMLChildNode);
				}
				else if(strTagName == FeedParserConsts.ATOM.MODIFIED)
				{
					strDate = XMLManager.GetXmlNodeValue(XMLChildNode);
				}
				
			}
			
			if(strLink)
			{
				this.AddFeedElement(strTitle,strLink,strDate);
			}
			
			
		}
	};
	
	this.AddFeedElement = function(strTitle,strLink,strDate)
	{
		var oFeedElement = new FeedElement(strTitle,strLink,strDate);
		this.Items[oFeedElement.Link] = oFeedElement;
	};
	
	this.GetFeedItems = function(XMLRoot)
	{
		var XMLFeedItems = null;
		//check rss
		XMLFeedItems = XMLRoot.getElementsByTagName(FeedParserConsts.RSS.ITEM);
		if(XMLFeedItems.length > 0)
		{
			this.Type	= FeedParserConsts.TYPE.RSS;
			return XMLFeedItems;
		}
		
		//check atom
		XMLFeedItems = XMLRoot.getElementsByTagName(FeedParserConsts.ATOM.ENTRY);
		if(XMLFeedItems.length > 0)
		{
			this.Type	= FeedParserConsts.TYPE.ATOM;
			return XMLFeedItems;
		}
		
		return null;
		
	};
	
	this.SetRSSFeedTitleLink = function(XMLRoot)
	{
		var strFeedTitle	= '';
		var strFeedLink		= '';
		var XMLChildNode	= null;
		var XMLChannelNode	= null;
		var strTagName		= '';
		
		for(var i=0;i<XMLRoot.childNodes.length;i++)
		{
			XMLChildNode = XMLRoot.childNodes[i];
			
			strTagName	 = XMLChildNode.tagName;
			if(typeof(strTagName) == 'string')
			{
				strTagName = strTagName.toLowerCase();
			}
			
			if(strTagName == FeedParserConsts.RSS.CHANNEL)
			{
				XMLChannelNode = XMLChildNode;
				break;
			}
		}
		
		if(XMLChannelNode)
		{
			for(var i=0;i<XMLChannelNode.childNodes.length;i++)
			{
				XMLChildNode = XMLChannelNode.childNodes[i];
				strTagName	 = XMLChildNode.tagName;
				if(typeof(strTagName) == 'string')
				{
					strTagName = strTagName.toLowerCase();
				}
				
				if(strTagName == FeedParserConsts.RSS.TITLE)
				{
					strFeedTitle = XMLManager.GetXmlNodeValue(XMLChildNode);
				}
				else if(strTagName == FeedParserConsts.RSS.LINK)
				{
					strFeedLink	= XMLManager.GetXmlNodeValue(XMLChildNode);
				}
				
				if(strFeedTitle && strFeedLink)
				{
					break;
				}
			}
		}
		this.Title		= strFeedTitle;
		this.Link		= strFeedLink;
	};
	
	this.SetATOMFeedTitleLink = function(XMLRoot)
	{
		var strFeedTitle	= '';
		var strFeedLink		= '';
		var XMLChildNode	= null;
		var strTagName		= '';
		
		for(var i=0;i<XMLRoot.childNodes.length;i++)
		{
			XMLChildNode = XMLRoot.childNodes[i];
			strTagName	 = XMLChildNode.tagName;
			if(typeof(strTagName) == 'string')
			{
				strTagName = strTagName.toLowerCase();
			}
			
			if(strTagName == FeedParserConsts.ATOM.TITLE)
			{
				strFeedTitle = XMLManager.GetXmlNodeValue(XMLChildNode);
			}
			else if(strTagName == FeedParserConsts.ATOM.LINK)
			{
				strFeedLink	= this.GetATOMLinkFromXMLLinkNode(XMLChildNode);
			}
			
			if(strFeedTitle && strFeedLink)
			{
				break;
			}
		}
		
		this.Title		= strFeedTitle;
		this.Link		= strFeedLink;
	};
	
	this.GetATOMLinkFromXMLLinkNode = function(XMLLinkNode)
	{
		var strLink = '';
	
		var oAttributes		= null;
		var oAttType		= null;
		var oAttHref		= null;
		
		oAttributes = XMLLinkNode.attributes;
		oAttHref	= oAttributes.getNamedItem(FeedParserConsts.ATOM.HREF);
		oAttType	= oAttributes.getNamedItem(FeedParserConsts.ATOM.TYPE);
		if(oAttHref && oAttType && oAttType.nodeValue.toLowerCase() == FeedParserConsts.ATOM.TEXTHTML)
		{
			strLink = oAttHref.nodeValue;
		}
		
		return strLink;
	};
	
	this.GetRSSLinkFromXMLGUIDNode = function(XMLGUIDNode)
	{
		var strLink = '';
		var oAttributes		= null;
		var oAttIsPermaLink	= null;
		
		oAttributes		= XMLGUIDNode.attributes;
		oAttIsPermaLink	= oAttributes.getNamedItem(FeedParserConsts.RSS.ISPERMALINK);
	
		if(!oAttIsPermaLink || oAttIsPermaLink.nodeValue.toLowerCase() == FeedParserConsts.RSS.TRUE)
		{
			strLink = XMLManager.GetXmlNodeValue(XMLGUIDNode);
		}
		
		return strLink;
	};
	
	this.Init(XMLDoc);
}


var FeedRequest = 
{
	ServerRequest : function(strURL)
	{
		//alert(strURL);
		var oRequest = new XMLHttpRequest();
		oRequest.open('GET', strURL, true);
		oRequest.onreadystatechange = function()
		{
			if(oRequest.readyState == 4)
  			{
	  			var XMLDoc = oRequest.responseXML;
	  			FeedRequest.ServerResponse(XMLDoc);
 	 		}
		};
		oRequest.send(null);
	},
	
	ServerResponse : function(XMLDoc)
	{
		var oFeedParser = new FeedParser(XMLDoc);
		
		var arrItems = oFeedParser.Items;

    moreDappsMenu = document.createElement('menu');

		//list for nav menu
		for(var item in arrItems)
		{			
			var menupopup = document.getElementById('Bzzster_Community_Links_Menu_Head').getElementsByTagName("menupopup")[0];
			var rssItem_Bzz_recent = document.createElement('menuitem');
			
			//prep favicon
			var url = arrItems[item].Link;
			var nohttp = url.split('//')[1];
			var hostPort = nohttp.split('/')[0];
			var favicon_img = "http://"+hostPort+"/favicon.ico";
			
			rssItem_Bzz_recent.setAttribute('id', "custom_css_menu");
			rssItem_Bzz_recent.setAttribute('label', arrItems[item].Title);
			rssItem_Bzz_recent.setAttribute('tooltiptext', arrItems[item].Link);
			rssItem_Bzz_recent.setAttribute('value', arrItems[item].Link );
			rssItem_Bzz_recent.setAttribute('class', 'menuitem-iconic');
			rssItem_Bzz_recent.setAttribute('image', favicon_img);
			rssItem_Bzz_recent.setAttribute('oncommand', 'ssOpenItemUrl(event.target);' );
			      
      menupopup.appendChild(rssItem_Bzz_recent);
      fetch_bzz_communitylinks = 1;
			
			//alert(arrItems[item].Title + '\n' + arrItems[item].Link + '\n' + arrItems[item].Date);
		}
		
		
		//list for context menu
		for(var item in arrItems)
		{			
			var menupopup = document.getElementById('Bzzster_ContextMenu_Community_Links_Menu_Head').getElementsByTagName("menupopup")[0];
			var rssItem_Bzz_recent = document.createElement('menuitem');
			
			//prep favicon
			var url = arrItems[item].Link;
			var nohttp = url.split('//')[1];
			var hostPort = nohttp.split('/')[0];
			var favicon_img = "http://"+hostPort+"/favicon.ico";
						
			rssItem_Bzz_recent.setAttribute('id', "custom_css_menu");
			rssItem_Bzz_recent.setAttribute('label', arrItems[item].Title);
			rssItem_Bzz_recent.setAttribute('tooltiptext', arrItems[item].Link);
			rssItem_Bzz_recent.setAttribute('value', arrItems[item].Link );
			rssItem_Bzz_recent.setAttribute('class', 'menuitem-iconic');
			rssItem_Bzz_recent.setAttribute('image', favicon_img);			
			rssItem_Bzz_recent.setAttribute('oncommand', 'ssOpenItemUrl(event.target);' );
			    
      menupopup.appendChild(rssItem_Bzz_recent);
      fetch_bzz_communitylinks = 1;
			
			//alert(arrItems[item].Title + '\n' + arrItems[item].Link + '\n' + arrItems[item].Date);
		}
	}
}




//DIGG PARSER//

function makeDiggRequest(url) {
	  http_request = false;
	  http_request = new XMLHttpRequest();
	  if (http_request.overrideMimeType) {
		  http_request.overrideMimeType('text/xml');
		  }
	  if (!http_request) {
		  //alert('Cannot create XMLHTTP instance');
		  return false;
		  }
	  http_request.onreadystatechange = alertDiggContents;
	  http_request.open('GET', url, true);
	  http_request.send(null);
	  return true;
}

function alertDiggContents() {
   if (http_request.readyState == 4) {
      if (http_request.status == 200) {
      
	     var xmlobject = http_request.responseXML;
	     var stories = xmlobject.getElementsByTagName('stories')[0];
			 var count = stories.getAttribute('count');
			 if (count > 0)
			 {
				 var story = stories.getElementsByTagName("story")[0];
				 var diggs = story.getAttribute("diggs");
				 var comments = story.getAttribute("comments");
				 var url = story.getAttribute("href");

				 bzz_digg_label = 'digg this' + '    - '+diggs+' diggs, '+comments+' comments';
				 document.getElementById(digg_id).label = bzz_digg_label;
				 
				 bzz_digg_url = url;
			 }
			 else
			 {
				 bzz_digg_label = 'digg this';
				 document.getElementById(digg_id).label = bzz_digg_label;
				 bzz_digg_url = 'http://digg.com/submit?phase=2&title='+encodeURIComponent(content.document.title)+'&url='+encodeURIComponent(content.location.href);
			 }
	      }
   }
}

function getDiggInfo(ele_digg_id) {
	digg_id = ele_digg_id;
	bzz_digg_label ='digg this';
	makeDiggRequest('http://services.digg.com/stories?count=1&appkey=http://bzzster.com&link='+encodeURIComponent(content.location.href));
}


//DELICIOUS PARSER//

function makeDeliciousRequest (url,ele_d_id){
		var var_id_del=ele_d_id;
		var delicious_http_request = new XMLHttpRequest();
		delicious_http_request.open('GET', url, true);
		delicious_http_request.onreadystatechange = function(){
			if(delicious_http_request.readyState == 4)
  			{
	  			var delicios_json_text = delicious_http_request.responseText;
	  			var delicios_json_object = YBJSON.parse(delicios_json_text);
	  			var delicious_urlinfo = '';
	  			var delicious_urlinfo = delicios_json_object[0];
	  			
	  			//case: empty json
	  			if (!delicious_urlinfo){
	  				bzz_delicious_label ='del.icio.us';
	  				document.getElementById(var_id_del).label = bzz_delicious_label;			
	  			}
	  			if (delicious_urlinfo){
	  				var delicious_posts = delicious_urlinfo.total_posts;
	  			}
				  if (delicious_posts > 0){
					  bzz_delicious_label = 'del.icio.us' + '  - ' + delicious_posts + ' saves';
					  document.getElementById(var_id_del).label = bzz_delicious_label;
				  }
				  else{
					  bzz_delicious_label = 'del.icio.us';
					  document.getElementById(var_id_del).label = bzz_delicious_label;				  
				  }
 	 		}
		};
		delicious_http_request.send(null);
}


function getDeliciousInfo(ele_d_id) {
  bzz_delicious_label ='del.icio.us';
	var url_md5hash = hex_md5(content.location.href);
	var delicious_json_query = 'http://badges.del.icio.us/feeds/json/url/data?hash='+url_md5hash;
	makeDeliciousRequest(delicious_json_query, ele_d_id);
}